Asset Hub Polkadot Runtime
Asset Hub Polkadot is a parachain that provides an interface to create, manage, and use assets. Assets may be fungible or non-fungible.
Renaming
This chain was originally known as “Statemint”. You may see references to Statemint, Statemine, and Westmint throughout the codebase. These are synonymous with “Asset Hub Polkadot, Kusama, and Westend”, respectively.
Assets
- Fungibles: Configuration of
pallet-assets. - Non-Fungibles (NFTs): Configuration of
pallet-uniques.
Other Functionality
Native Balances
Asset Hub Polkadot uses its parent DOT token as its native asset.
Governance
As a system parachain, Asset Hub defers its governance (namely, its Root origin), to its
Relay Chain parent, Polkadot.
Collator Selection
Asset Hub uses pallet-collator-selection, a simple first-come-first-served registration
system where collators can reserve a small bond to join the block producer set. There is no
slashing.
XCM
Because Asset Hub is fully under the control of the Relay Chain, it is meant to be a
TrustedTeleporter. It can also serve as a reserve location to other parachains for DOT as well
as other local assets.
Re-exports
pub use parachains_common as common;
Modules
Structs
- Announcement
Deposit Base - Announcement
Deposit Factor - Approval
Deposit - Asset
Account Deposit - Asset
Deposit - Assets
String Limit - Deposit
Base - Deposit
Factor - Existential
Deposit - Fellows
Body Id - Foreign
Assets Approval Deposit - Foreign
Assets Asset Account Deposit - Foreign
Assets Asset Deposit - Foreign
Assets Assets String Limit - Foreign
Assets Metadata Deposit Base - Foreign
Assets Metadata Deposit PerByte - MaxPending
- MaxProxies
- MaxSignatories
- Message
Queue Service Weight - Metadata
Deposit Base - Key = 32 bytes, Value = 36 bytes (32+1+1+1+1)
- Metadata
Deposit PerByte - Nfts
Attribute Deposit Base - Nfts
Collection Deposit - Nfts
Deposit PerByte - Nfts
Item Deposit - Nfts
MaxDeadline Duration - Nfts
Metadata Deposit Base - Nfts
Pallet Features - Offset
- Pallet
Info - Provides an implementation of
PalletInfoto provide information about the pallet setup in the runtime. - Period
- PotId
- Proxy
Deposit Base - Proxy
Deposit Factor - Relay
Origin - Reserved
DmpWeight - Reserved
Xcmp Weight - Runtime
- Runtime
Api - Runtime
ApiImpl - Implements all runtime apis for the client side.
- Runtime
Block Length - Runtime
Block Weights - Runtime
Genesis Config - Runtime
Origin - The runtime origin type representing the origin of a call.
- SS58
Prefix - Session
Keys - Session
Length - Staking
Admin Body Id - Transaction
Byte Fee - Relay Chain
TransactionByteFee/ 10 - Uniques
Attribute Deposit Base - Uniques
Collection Deposit - Uniques
Deposit PerByte - Uniques
Item Deposit - Uniques
Metadata Deposit Base - Version
Enums
- Origin
Caller - Proxy
Type - The type used to represent the kinds of proxying allowed.
- Runtime
Call - Runtime
Error - Runtime
Event - Runtime
Freeze Reason - A reason for placing a freeze on funds.
- Runtime
Hold Reason - A reason for placing a hold on funds.
- Runtime
Lock Id - An identifier for each lock placed on funds.
- Runtime
Slash Reason - A reason for slashing funds.
Constants
Traits
- Build
Storage - Complex storage builder stuff.
Functions
- native_
version - The version information used to identify this runtime when compiled natively.
Type Aliases
- Address
- The address format for describing accounts.
- AllPallets
Deprecated - All pallets included in the runtime as a nested tuple of types.
- AllPallets
Reversed With System First Deprecated - All pallets included in the runtime as a nested tuple of types in reversed order. With the system pallet first.
- AllPallets
With System - All pallets included in the runtime as a nested tuple of types.
- AllPallets
With System Reversed Deprecated - All pallets included in the runtime as a nested tuple of types in reversed order.
- AllPallets
Without System - All pallets included in the runtime as a nested tuple of types. Excludes the System pallet.
- AllPallets
Without System Reversed Deprecated - All pallets included in the runtime as a nested tuple of types in reversed order. Excludes the System pallet.
- Asset
TxPayment - Assets
- Assets
Force Origin - We allow root to execute privileged asset operations.
- Aura
- Aura
Config - AuraExt
- Aura
ExtConfig - Authorship
- Balances
- Balances
Config - Block
- Block type as expected by this runtime.
- BlockId
- BlockId type as expected by this runtime.
- Collator
Selection - Collator
Selection Config - Collator
Selection Update Origin - We allow root and the
StakingAdminto execute privileged collator selection operations. - Cumulus
Xcm - DmpQueue
- Executive
- Executive: handles dispatch to the various modules.
- Foreign
Assets - Foreign
Assets Instance - Assets managed by some foreign location. Note: we do not declare a
ForeignAssetsCalltype, as this type is used in proxy definitions. We assume that a foreign location would not want to set an individual, local account as a proxy for the issuance of their assets. This issuance should be managed by the foreign location’s governance. - Genesis
Config Deprecated - Message
Queue - Migrations
- Migrations to apply on runtime upgrade.
- Multisig
- Nfts
- Parachain
Info - Parachain
Info Config - Parachain
System - Parachain
System Config - Polkadot
Xcm - Polkadot
XcmConfig - Proxy
- Session
- Session
Config - Signed
Block - A Block signed with a Justification
- Signed
Extra - The SignedExtension to the basic transaction logic.
- System
- System
Config - Timestamp
- Transaction
Payment - Trust
Backed Assets Instance - Unchecked
Extrinsic - Unchecked extrinsic type as expected by this runtime.
- Uniques
- Utility
- Xcmp
Queue